@@ -1,29 +1,35 @@
 
 package Importer::Zim::Utils;
-$Importer::Zim::Utils::VERSION = '0.7.0';
+$Importer::Zim::Utils::VERSION = '0.8.0';
 # ABSTRACT: Utilities for Importer::Zim backends
 
 use 5.010001;
 
 our @EXPORT_OK = qw(DEBUG carp croak);
 
-sub DEBUG () { $ENV{IMPORTER_ZIM_DEBUG} || 0 }
+BEGIN {
+    my $v = $ENV{IMPORTER_ZIM_DEBUG} || 0;
+    *DEBUG = sub () {$v};
+}
 
 sub carp  { require Carp; goto &Carp::carp; }
 sub croak { require Carp; goto &Carp::croak; }
 
 ### import / unimport machinery
 
-sub USE_LEXICAL_SUBS () {    # Is Sub::Inject loaded?
-    require Module::Runtime;
-    return !!$INC{ Module::Runtime::module_notional_filename('Sub::Inject') };
+BEGIN {
+    my $v
+      = $ENV{IMPORTER_ZIM_NO_LEXICAL}
+      ? !1
+      : !!eval 'use Sub::Inject 0.2.0 (); 1';
+    *USE_LEXICAL_SUBS = sub () {$v};
 }
 
 sub import {
     my $exports = shift->_get_exports(@_);
 
     if (USE_LEXICAL_SUBS) {
-        @_ = ($exports);
+        @_ = %$exports;
         goto &Sub::Inject::sub_inject;
     }
 
@@ -98,7 +104,7 @@ Importer::Zim::Utils - Utilities for Importer::Zim backends
 
 =head1 VERSION
 
-version 0.7.0
+version 0.8.0
 
 =head1 SYNOPSIS
 
